<?php

/**
 * @file
 * Admin pages for Session 443 module.
 */

/**
 * Admin settings form.
 *
 * @ingroup forms
 */
function session443_settings_form(&$form_state) {

  $form['session443_enable'] = array(
    '#type' => 'radios',
    '#title' => t('Enable Session 443'),
    '#default_value' => variable_get('session443_enable', 0),
    '#options' => array(t('Disabled'), t('Enabled')),
    '#disabled' => !_session443_test_https(),
    '#description' => '<p>' . t('Force all authenticated users to use HTTPS. Also force non-authenticated users on a login or registration form to use HTTPS.  Otherwise force HTTP. If your site becomes unusable after enabling, please read the README.txt file.') . '</p><p>' .
      t('This setting can only be changed if the web server has been configured properly for HTTPS. If this test has failed then you may attempt to override it <a href="!url">here</a>.', array('!url' => _session443_modify_url_scheme(url($_GET['q'], array('absolute' => TRUE))))) .'</p>',
  );

  $form['session443_login_block'] = array(
    '#type' => 'radios',
    '#title' => t('Login block'),
    '#default_value' => variable_get('session443_login_block', SESSION443_LOGIN_BLOCK_FORCE_HTTPS),
    '#options' => array(
      SESSION443_LOGIN_BLOCK_FORCE_HTTPS => t('Force all pages with the login block to use HTTPS.'),
      SESSION443_LOGIN_BLOCK_CHANGE_FORM_ACTION => t('Only change the URL that the form is submitted to to use HTTPS.  There will be no browser lock icon on pages with the login block.  <a href="http://drupal.org/node/812572#comment-3897304">More information</a>.'),
      SESSION443_LOGIN_BLOCK_NONE => t("Don't do any manipulations of the login block."),
    ),
    '#description' => t('By default Session 443 forces all pages that have a login form to use HTTPS.  If you use the login block to place this form on every page this may add unreasonable load to your server (HTTPS requires more server resources).  This setting is only important if you use the login block.'),
  );

  $form['session443_additional_pages'] = array(
    '#type' => 'textarea',
    '#title' => t('Additional pages to make secure'),
    '#description' => t("Enter one page per line as Drupal paths. The '*' character is a wildcard. Example paths are %blog for the blog page and %blog-wildcard for every personal blog. %front is the front page.", array('%blog' => 'blog', '%blog-wildcard' => 'blog/*', '%front' => '<front>')),
    '#wysiwyg' => FALSE,
    '#default_value' => variable_get('session443_additional_pages', 'cart*'),
  );

  $form['session443_ignore_pages'] = array(
    '#type' => 'textarea',
    '#title' => t('Ignore pages'),
    '#description' => t("The pages listed here will be ignored and be either returned in HTTP or HTTPS. Enter one page per line as Drupal paths. The '*' character is a wildcard. Example paths are %blog for the blog page and %blog-wildcard for every personal blog. %front is the front page.", array('%blog' => 'blog', '%blog-wildcard' => 'blog/*', '%front' => '<front>')),
    '#wysiwyg' => FALSE,
    '#default_value' => variable_get('session443_ignore_pages', "*/autocomplete/*\n*/ajax/*\n*/ahah/*"),
  );

  return system_settings_form($form);
}

// vim: set filetype=php expandtab tabstop=2 shiftwidth=2 autoindent smartindent:
